#
# spec file for package caribou
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           caribou
Version:        0.4.21
Release:        9.3
# FIXME: Stop hiding the .desktop file with %%suse_update_desktop_file -u if launching caribou finally works
Summary:        On-screen Keyboard for GNOME
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            http://live.gnome.org/Caribou
Source0:        http://download.gnome.org/sources/caribou/0.4/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM caribou-vala-build-fix.patch boo#1186617 mgorse@suse.com -- fix the build with newer valac versions.
Patch0:         caribou-vala-build-fix.patch
# PATCH-FIX-UPSTREAM caribou-CVE-2021-3567.patch boo#1186617 mgorse@suse.com -- fix segfault when attempting to use shifted characters.
Patch1:         caribou-CVE-2021-3567.patch
# PATCH-FIX-UPSTREAM caribou-stop-patching-gir.patch mgorse@suse.com -- stop patching the GIR.
Patch2:         caribou-stop-patching-gir.patch
# PATCH-FIX-UPSTREAM caribou-css-fix.patch boo#1187112 mgorse@suse.com -- fix failure to start in GNOME flashback.
Patch3:         caribou-css-fix.patch
# Needed for Patch2
BuildRequires:  libtool
# For directory ownership
BuildRequires:  dbus-1
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-gobject >= 3.18
BuildRequires:  python3-xml
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.13
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(atspi-2)
BuildRequires:  pkgconfig(clutter-1.0)
BuildRequires:  pkgconfig(gdk-3.0) >= 3.0.0
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxklavier)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pygobject-3.0) >= 2.90.3
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xtst)
Requires:       python3-atspi
Requires:       python3-xml
%glib2_gsettings_schema_requires

%description
Caribou is a text entry and UI navigation application being developed
as an alternative to the Gnome On-screen Keyboard. The overarching goal
for Caribou is to create a usable solution for people whose primary way
of accessing a computer is a switch device.

%package gtk-module-common
Summary:        On-screen Keyboard for GNOME -- Common Files for GTK+ Modules
Group:          System/GUI/GNOME
Recommends:     %{name}-gtk2-module
Recommends:     %{name}-gtk3-module

%description gtk-module-common
Caribou is a text entry and UI navigation application being developed
as an alternative to the Gnome On-screen Keyboard. The overarching goal
for Caribou is to create a usable solution for people whose primary way
of accessing a computer is a switch device.

This package contains files common to both the GTK+ 2 and GTK+ 3
modules.

%package gtk2-module
Summary:        On-screen Keyboard for GNOME -- GTK+ 2 Module
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Requires:       %{name}-gtk-module-common = %{version}
Supplements:    packageand(%{name}:gtk2)

%description gtk2-module
Caribou is a text entry and UI navigation application being developed
as an alternative to the Gnome On-screen Keyboard. The overarching goal
for Caribou is to create a usable solution for people whose primary way
of accessing a computer is a switch device.

%package gtk3-module
Summary:        On-screen Keyboard for GNOME -- GTK+ 3 Module
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Requires:       %{name}-gtk-module-common = %{version}
Supplements:    packageand(%{name}:gtk3)

%description gtk3-module
Caribou is a text entry and UI navigation application being developed
as an alternative to the Gnome On-screen Keyboard. The overarching goal
for Caribou is to create a usable solution for people whose primary way
of accessing a computer is a switch device.

%package -n libcaribou0
Summary:        On-screen Keyboard for GNOME -- Library
Group:          System/Libraries
Requires:       %{name}-common >= %{version}

%description -n libcaribou0
Caribou is a text entry and UI navigation application being developed
as an alternative to the Gnome On-screen Keyboard. The overarching goal
for Caribou is to create a usable solution for people whose primary way
of accessing a computer is a switch device.

%package common
Summary:        On-screen Keyboard for GNOME -- Common data files
Group:          System/Libraries

%description common
Caribou is a text entry and UI navigation application being developed
as an alternative to the Gnome On-screen Keyboard. The overarching goal
for Caribou is to create a usable solution for people whose primary way
of accessing a computer is a switch device.

%package -n typelib-1_0-Caribou-1_0
Summary:        On-screen Keyboard for GNOME -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Caribou-1_0
Caribou is a text entry and UI navigation application being developed
as an alternative to the Gnome On-screen Keyboard. The overarching goal
for Caribou is to create a usable solution for people whose primary way
of accessing a computer is a switch device.

This package provides the GObject Introspection bindings for the caribou
library.

%package devel
Summary:        On-screen Keyboard for GNOME -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libcaribou0 = %{version}
Requires:       typelib-1_0-Caribou-1_0 = %{version}

%description devel
Caribou is a text entry and UI navigation application being developed
as an alternative to the Gnome On-screen Keyboard. The overarching goal
for Caribou is to create a usable solution for people whose primary way
of accessing a computer is a switch device.

%lang_package

%prep
%autosetup -p1

%build
# Needed for patch2
autoreconf -fi
export CFLAGS="$CFLAGS -Wno-error=incompatible-pointer-types"
%configure \
    --disable-static     \
    --enable-gtk3-module \
    --enable-gtk2-module PYTHON=python3
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}
# FIXME: We have to unhide this when the application gets its icon (bnc#726954, bgo#618293) and when caribou actually works
%suse_update_desktop_file %{name}-autostart
%fdupes %{buildroot}

%post -n libcaribou0 -p /sbin/ldconfig
%postun -n libcaribou0 -p /sbin/ldconfig

%files
%license COPYING
%doc README
%{_bindir}/caribou-preferences
%{python3_sitelib}/caribou/
%{_datadir}/antler/
%{_datadir}/dbus-1/services/org.gnome.Caribou.Antler.service
%{_datadir}/dbus-1/services/org.gnome.Caribou.Daemon.service
%{_datadir}/glib-2.0/schemas/org.gnome.antler.gschema.xml
%{_libexecdir}/antler-keyboard
%{_libexecdir}/caribou
%{_sysconfdir}/xdg/autostart/caribou-autostart.desktop

%files gtk-module-common
%dir %{_libdir}/gnome-settings-daemon-3.0
%dir %{_libdir}/gnome-settings-daemon-3.0/gtk-modules
%{_libdir}/gnome-settings-daemon-3.0/gtk-modules/caribou-gtk-module.desktop

%files gtk2-module
%{_libdir}/gtk-2.0/modules/libcaribou-gtk-module.so

%files gtk3-module
%{_libdir}/gtk-3.0/modules/libcaribou-gtk-module.so

%files -n libcaribou0
%{_libdir}/libcaribou.so.*

%files common
%{_datadir}/caribou/
%{_datadir}/glib-2.0/schemas/org.gnome.caribou.gschema.xml

%files -n typelib-1_0-Caribou-1_0
%{_libdir}/girepository-1.0/Caribou-1.0.typelib

%files devel
%{_datadir}/gir-1.0/*.gir
%{_datadir}/vala/vapi/caribou-1.0.*
%{_includedir}/libcaribou/
%{_libdir}/libcaribou.so
%{_libdir}/pkgconfig/caribou-1.0.pc

%files lang -f %{name}.lang

%changelog
* Tue Aug 20 2024 Michael Gorse <mgorse@suse.com>
- Pass -Wno-error=incompatible-pointer-types. Suppresses error on
  gcc 14.
* Mon Jan 17 2022 Yifan Jiang <yfjiang@suse.com>
- Add python-rpm-macros BuildRequires in case some build
  environment does not pull it automatically. This is needed by
  macros like %%{python3_sitelib}.
* Wed Jun 30 2021 Michael Gorse <mgorse@suse.com>
- Add caribou-stop-patching-gir.patch: stop patching the GIR.
  Taken from upstream; the build now fails without this. Also add
  libtool to BuildRequires.
- Add caribou-css-fix.patch: fix failure to start in GNOME
  flashback (boo#1187112).
* Wed Jun  2 2021 Michael Gorse <mgorse@suse.com>
- Add caribou-vala-build-fix.patch: fix build with newer valac
  versions (boo#1186617).
- Add caribou-CVE-2021-3567.patch: fix segfault when attempting to
  use shifted characters (boo#1186617 CVE-2021-3567).
* Mon Feb 10 2020 Frederic Crozat <fcrozat@suse.com>
- Add python3-gobject BuildRequires: We eliminated an auto-pull-in
  of the python stack for consumers of the C-headers. Caribou uses
  both.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Nov 29 2017 dimstar@opensuse.org
- Drop %%py_requires: this is a python2 dependency, but the package
  was already migrated to python3.
* Fri Nov 10 2017 fcrozat@suse.com
- Switch build to python3.
- Remove glib2_gsettings_schema macros calls in post/postun, not
  needed anymore with filetriggers.
* Mon Jul 25 2016 zaitor@opensuse.org
- Update to version 0.4.21:
  + bgo#768104: Initialize Clutter explicitly in antler code.
  + bgo#768105: Fix theme parsing error for antler keyboard
    style.css.
  + bgo#767664: Add missing python3 compatibility.
  + Updated translations.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 0.4.20:
  + bgo#758490: Please make caribou compatible with python3.
  + bgo#759896: German (qwertz) fullscale layout.
  + bgo#760470: Proposing a new fullscale keyboard layout.
  + bgo#756623: No Polish diacritic letters.
  + Updated translations.
* Tue Oct 13 2015 zaitor@opensuse.org
- Update to version 0.4.19:
  + xadapter: Avoid a crash when Xkl doesn't know the real xkb
    groups (bgo#756194).
* Wed Apr 15 2015 zaitor@opensuse.org
- Update to version 0.4.18.1:
  + bgo#747273: display-adapter: Allow setting an external default
    adapter instance.
  + Updated translations.
* Fri Mar 20 2015 badshah400@gmail.com
- Update to version 0.4.18:
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 0.4.17:
  + Bundle tools to generate and manipulate keyboard layout files.
  + bgo#691811: Add support for azerty layout as seen in french.
  + bgo#743267: Caribou does 100-130 syscalls for each keypress.
  + bgo#743880: String that is hard to understand.
  + Updated translations.
* Mon Nov 24 2014 zaitor@opensuse.org
- Update to version 0.4.16:
  + Stop using deprecated accessibility events ("focus:*").
  + bgo#739837: Allow label overwrite in keyboard layout.
  + bgo#739716: Add more keys to label_map.
  + bgo#739711: Escape key does not work in us layout.
  + bgo#739526: Some buttons do not have a label.
  + bgo#722634: [regression] build failure: ImportError: No module
    named 'caribou_settings'.
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 0.4.15:
  + Fix race condition when invoking OSK through D-Bus
    (bgo#683712).
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 0.4.14:
  + bgo#720653: some string in daemon.vala is not available for
    translation.
  + bgo#722355: #!/usr/bin/python in tools/fix_gir.py.
  + bgo#735504: Fails to build with latest vala.
  + bgo#683712: Invocation of on screen keyboard.
  + Updated translations.
* Fri Mar 14 2014 mgorse@suse.com
- Move caribou schema and keyboard layout files to a caribou-common
  package. They are required by libcaribou, which is used by
  gnome-shell if the on-screen keyboard is enabled. (bnc#861360)
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 0.4.13:
  + bgo#698746: Accessibility: "slow keys" breaks "screen keyboard"
    feature.
  + Updated translations.
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 0.4.12:
  + libcaribou: factor out X dependency (bgo#705720).
  + Updated translations.
* Tue Jun  4 2013 zaitor@opensuse.org
- Update to version 0.4.11:
  + Press and hold should allow repeating keys like backspace and
    spacebar (bgo#690435).
  + Improve layout file generation when building.
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 0.4.10:
  + Add --help option to caribou command.
  + Updated translations.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 0.4.9:
  + daemon: check if atspi bus is ready to use (bgo#694921).
  + Setting keyboard to 'full' crashes the shell (bgo#689844).
  + build: Mark as not supporting srcdir != builddir.
  + Bugs fixed: bgo#694480.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 0.4.8:
  + Don't rebuild docs on every "make" run.
  + Add missing symbols to fullscale layouts as well.
  + Bugs fixed: bgo#694011, bgo#688218, bgo#680556, bgo#693616,
    bgo#684887, bgo#691992.
  + Updated translations.
- Add pkgconfig(atspi-2) and pkgconfig(gdk-3.0) BuildRequires: new
  verified dependencies.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 0.4.7:
  + bgo#687244: Add documentation support
  + bgo#687315: various packaging fixes:
  - build: only export public symbols from the library
  - build: make sure to define $datarootdir in generated scripts
  - build: suppress Python bytecode generation when building
  - build: install vapi file
  - build: install pkg-config file
  - build: use git.mk
  - build: don't use deprecated Automake variable INCLUDE
  - build: rename caribou.pc to caribou-1.0.pc
  + bgo#691463: libcaribou: avoid integer overflow
  + Fix 'make install' when --enable-docs is used
  + Updated translations.
* Tue Dec 18 2012 dimstar@opensuse.org
- Update to version 0.4.6:
  + bgo#688517: libcaribou: refactor some code
  + bgo#688656: key-model: Use key-released instead of key-clicked
    to hide subkeys
  + bgo#689823: caribou-preferences: Fix expansion of
    LD_LIBRARY_PATH
  + Updated translations.
* Tue Nov 20 2012 dimstar@opensuse.org
- Update to version 0.4.5:
  + xadapter:
  - use level3 shift if possible (bgo#687018)
  - use XkbChangeMap instead of XkbSetMap (bgo#673547)
  - specify core device when callin XkbSetMap (bgo#673547)
  + Portability: allow the use of /bin/sh instead of /bin/bash.
  + libcaribouu:
  - simplify using xtst.vapi provided by vala (bgo#685607)
  - Ignore level 3 keysyms when looking up keycode (bgo#673579)
  + xml: add "text" attribute to key (bgo#687026)
  + Port from libgee 0.6 to 0.8
  + Bugs fixed: bgo#667455, bgo#656175, bgo#673543, bgo#686200.
  + Updated translations.
- Replace pkgconfig(gee-1.0) with pkgconfig(gee-0.8), following
  upstreams port to libgee 0.8.
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 0.4.4.2:
  + Use GDBus directly instead of dbus-python (bgo#685792).
  + Use "=" operator instead of "==" in shell scripts (bgo#685629).
  + Fix border-image slice values in antler's gtk CSS (bgo#687409).
* Wed Sep  5 2012 dimstar@opensuse.org
- Update to version 0.4.4:
  + Removed unneeded gnome-doc-utils dependency
  + caribou unnecessarily requires pygobject 3.3.3 or up to build
    (bgo#683256)
  + Updated translations.
- Drop gnome-doc-utils-devel BuildRequires: no longer needed.
- Add xsltproc BuildRequries: needed for the documentation
  handling.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 0.4.3:
  + bgo#674344: Not using units gtk CSS is deprecated
  + bgo#676746: Follow pygobject changes.
  + Updated translations.
* Tue Jun 26 2012 dimstar@opensuse.org
- Add bgo ref to the FIXME for the missing icon (bnc#726954).
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 0.4.2:
  + Build fixes.
  + Updated translations.
* Fri Dec 23 2011 vuntz@opensuse.org
- Split typelib file into typelib-1_0-Caribou-1_0 subpackage.
- Add typelib-1_0-Caribou-1_0 Requires to devel subpackage.
- Add missing libcaribou0 Requires to devel subpackage.
* Thu Oct 27 2011 badshah400@gmail.com
- Pass -u to %%suse_update_desktop_file call for
  caribou.desktop to hide the application in the list of
  applications: the application has no icon and makes the desktop
  menu ugly (bgo#618293, bnc#726954), and starting it directly
  doesn't work right now.
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 0.4.1:
  + Autostart only in GNOME and Unity (bgo#660901).
  + Updated translations.
- Drop caribou-autostart-OnlyShowIn.patch: fixed upstream.
* Fri Oct  7 2011 vuntz@opensuse.org
- Add caribou-autostart-OnlyShowIn.patch: only autostart caribou in
  GNOME and Unity as only gnome-session-based desktops understand
  the AutostartCondition. Fix bnc#720239.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 0.4.0:
  + Don't try to replace an existing keyboard service (bgo#659867).
  + Fix header installation (bgo#659793).
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 0.3.92:
  + Add gio-2.0 to configure.ac (bgo#658969).
  + Fix GTK+ module loading/unloading and autoload (bgo#655979).
  + Don't add the event filter until the dbus call finishes
    (bgo#658063).
  + Set correct share-library in gir typelib (bgo#658345).
  + Fixed antler script for Fedora 64 bitfriendly packages
    (bgo#658533).
  + Fix caribou daemon to use new keyboard DBus API (bgo#658533).
  + Updated translations.
- Drop caribou-fix-typelib.patch: fixed upstream.
- Add pkgconfig(gio-2.0) BuildRequires: new explicit dependency
  upstream.
- Create a gtk-module-common subpackage, to contain files common to
  both gtk2-module and gtk3-module subpackages.
- Add Requires on gtk-module-common subpackage to gtk2-module and
  gtk3-module subpackages.
* Tue Sep 13 2011 vuntz@opensuse.org
- Add caribou-fix-typelib.patch: fix the typelib to reference the
  non-devel library (.so.0 instead of .so), so we don't need the
  devel subpackage for caribou to work.
- Add call to autoreconf, needed for above patch.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 0.3.91:
  + Update Antler to latest GTK+ 3.2 shenanigans.
  + Require pygobject 3.0.
  + Fixes to bugs that were.
  + Updated translations.
- Add explicit pkgconfig() BuildRequires for existing dependencies:
  libxml-2.0, x11, xtst.
- Remove now unneeded pkgconfig(pygobject-2.0) BuildRequires.
- Remove now unneeded python-virtkey Requires.
- Also build the GTK+ 2 module since there's no reason to not use
  the on-screen keyboard from GTK+ 2:
  + Add pkgconfig(gtk+-2.0) BuildRequires.
  + Pass --enable-gtk2-module to configure, instead of
  - -disable-gtk2-module.
- Split GTK+ 2/3 modules in gtk2-module and gtk3-module
  subpackages.
* Tue Aug 23 2011 dimstar@opensuse.org
- Add pkgconfig(pygobject-3.0) BuildRequires to help the build over
  the fact that the gi-bindings now live in python-gobject package.
* Fri Aug 12 2011 dimstar@opensuse.org
- Update to version 0.3.5:
  + Added modifiers support.
  + Replaced IM module with GTK+ module so it does not override the
    user's preferred IM.
  + Added "full scale" keyboards to caribou.
  + Remove emoticon buttons, for now.
  + Updated translations.
- Add lang subpackage Recommends from the main package.
- Pass --enable-gtk3-module and --disable-gtk2-module to
  configure.
* Sat Jul  9 2011 dimstar@opensuse.org
- Update to version 0.3.3:
  + Converted layout files to preprocessed XML files that could
    include external layout files and override specific elements.
  + Fixed GI in Makefiles/configure.ac (bgo#653268).
  + Fixed typo in IM configuring (bgo#653754).
  + Updated translations.
* Fri Jun 17 2011 dimstar@opensuse.org
- Update to version 0.3.2:
  + Rewritten almost entirely from scratch, featuring a GObject
    library for a DBus activated OSK.
  + Updated translations.
- Add pkgconfig(gee-1.0), pkgconfig(libxklavier), vala and dbus-1
  BuildRequires.
- Add gobject-introspection-devel BuildRequires to get typelib()-
  style provides. As a consequence, remove the explicitl Requires
  on gconf2, linclutter-glx-1_0-0 and libgtk-3-0.
- Split out libcairbou0 as per SLPP and a -devel package.
- Delete libtool archives.
* Wed Apr  6 2011 fcrozat@novell.com
- Update to version 0.2.00:
  + Use /org/gnome as starting path for schemas
  + Updated translations.
- Changes from version 0.1.92:
  + Separate autorun desktop file.
  + Updated translations.
- Changes from version 0.1.91:
  + Raise an error when no keyboard is loaded.
  + Make caribou startup automatically
  + Use GTK3 CSS theming for custom colors.
  + Look if a11y is enabled in GSettings.
  + Port app preferences and schema to GSettings.
  + Updated translations.
- Changes from version 0.1.7:
  + Ported to GTK3 and PyGI.
  + New Japanese keyboard.
  + Many bugs fixed.
  + Updated translations.
- Changes from version 0.1.6:
  + Added basic scanning support.
  + Added proper key highlight colors.
  + Cleaned up configuration and preferences and made it more MVC
    like.
  + Created cleaner preferences window.
  + Updated translations.
- Changes from version 0.1.5:
  + Added configurable key and highlight colors (bgo#622246).
  + Added a desktop file (bgo#618292).
  + Fix layout retrieval (bgo#622221).
  + Don't change layout when switching focus (bgo#621654).
  + Unpress modifier when Caribou quites (bgo#621596).
  + Source files reshuffling.
  + Added JSON/XML configurable layouts (bgo#613229).
  + Updated translations.
- Changes from version 0.1.2:
  + First development release for GNOME 3.0.
  + Updated translations.
- Drop caribou-fix-listdir.patch: fixed upstream
- Handle GSettings schemas, with %%glib2_gsettings_schema_* macros.
- Add BuildRequires: fdupes, gnome-doc-utils-devel, intltool,
  python-xml, update-desktop-files, pkgconfig(clutter-1.0),
  pkgconfig(gtk+-3.0), pkgconfig(pygobject-2.0).
- Add python-xml Requires.
- Remove icon from caribou.desktop with a sed, since the icon is
  not shipped at all.
* Fri Apr  2 2010 vuntz@opensuse.org
- Initial package.
